import boto3
from pkrhistoryparser.summary_parsers.abstract import AbstractSummaryParser


class CloudSummaryParser(AbstractSummaryParser):
    def __init__(self, bucket_name: str):
        self.bucket_name = bucket_name
        self.s3 = boto3.client("s3")
        self.raw_prefix = "data/summaries/raw"
        self.parsed_prefix = "data/summaries/parsed"

    def list_summary_keys(self) -> list:
        paginator = self.s3.get_paginator("list_objects_v2")
        pages = paginator.paginate(Bucket=self.bucket_name, Prefix=self.raw_prefix)
        keys = [obj["Key"] for page in pages for obj in page.get("Contents", [])]
        return keys

    def get_text(self, file_key: str) -> str:
        response = self.s3.get_object(Bucket=self.bucket_name, Key=file_key)
        content = response["Body"].read().decode("utf-8")
        return content

    def check_is_parsed(self, summary_key: str) -> bool:
        parsed_key = self.get_parsed_key(summary_key)
        response = self.s3.list_objects_v2(Bucket=self.bucket_name, Prefix=parsed_key)
        return "Contents" in response

    def save_parsed_summary(self, summary_key: str, json_summary: str) -> None:
        parsed_key = self.get_parsed_key(summary_key)
        self.s3.put_object(Bucket=self.bucket_name, Key=parsed_key, Body=json_summary)



import json
from ..history_parsers.cloud import CloudHandHistoryParser


def lambda_handler(event, context):
    for record in event['Records']:
        body = record['body']
        body_dict = json.loads(body)
        message = body_dict["Message"]
        message_dict = json.loads(message)
        message_record = message_dict["Records"][0]
        bucket_name = message_record['s3']['bucket']['name']
        key = message_record['s3']['object']['key']
        print(f"Parsing file {key}")
        try:
            parser = CloudHandHistoryParser(bucket_name)
            parser.parse_hand_history(key)
            return {
                'statusCode': 200,
                'body': f'File {key} processed successfully as parsed hand to {parser.get_parsed_key(key)}'
            }
        except Exception as e:
            print(f"Error in lambda_handler: {e}")
            return {
                'statusCode': 500,
                'body': f'Error processing file {key}: {e}'
            }



import os
from .abstract import AbstractSummaryParser


class LocalSummaryParser(AbstractSummaryParser):

    def __init__(self, data_dir: str):
        data_dir = self.correct_data_dir(data_dir)
        self.raw_dir = os.path.join(data_dir, "summaries", "raw")
        self.parsed_dir = os.path.join(data_dir, "summaries", "parsed")

    @staticmethod
    def correct_data_dir(data_dir: str) -> str:
        if not os.path.exists(data_dir):
            data_dir = data_dir.replace("C:/", "/mnt/c/")
        return data_dir

    def list_summary_keys(self) -> list:
        summaries_list = [os.path.join(root, file)
                          for root, _, files in os.walk(self.raw_dir)
                          for file in files if file.endswith(".txt")]
        return summaries_list

    def get_text(self, file_key: str) -> str:
        with open(file_key, "r", encoding="utf-8") as file:
            content = file.read()
        return content

    def check_is_parsed(self, summary_key: str) -> bool:
        parsed_key = self.get_parsed_key(summary_key)
        return os.path.exists(parsed_key)

    def save_parsed_summary(self, summary_key: str, json_summary: str) -> None:
        parsed_key = self.get_parsed_key(summary_key)
        os.makedirs(os.path.dirname(parsed_key), exist_ok=True)
        with open(parsed_key, "w", encoding="utf-8") as file:
            file.write(json_summary)



import os
from dotenv import load_dotenv
load_dotenv()

DATA_DIR = os.environ.get("DATA_DIR")
HISTORIES_DIR = os.path.join(DATA_DIR, "histories")
SUMMARIES_DIR = os.path.join(DATA_DIR, "summaries")
SPLIT_HISTORIES_DIR = os.path.join(HISTORIES_DIR, "split")
PARSED_HISTORIES_DIR = os.path.join(HISTORIES_DIR, "parsed")
BUCKET_NAME = os.environ.get("BUCKET_NAME")

if __name__ == "__main__":
    print(DATA_DIR)





import boto3
from .abstract import AbstractHandHistoryParser


class CloudHandHistoryParser(AbstractHandHistoryParser):

    def __init__(self, bucket_name: str):
        self.bucket_name = bucket_name
        self.s3 = boto3.client("s3")
        self.data_dir = "data"
        self.split_dir = "data/histories/split"
        self.parsed_dir = "data/histories/parsed"
        self.correction_split_keys_file_key = "data/correction_split_keys.txt"
        self.correction_parsed_keys_file_key = "data/correction_parsed_keys.txt"

    def list_split_histories_keys(self, directory_key: str = None) -> list:
        paginator = self.s3.get_paginator("list_objects_v2")
        directory = directory_key or self.split_dir
        pages = paginator.paginate(Bucket=self.bucket_name, Prefix=directory)
        keys = [obj["Key"] for page in pages for obj in page.get("Contents", [])]
        return keys

    def get_text(self, key: str) -> str:
        response = self.s3.get_object(Bucket=self.bucket_name, Key=key)
        content = response["Body"].read().decode("utf-8")
        return content

    def write_text(self, key: str, content: str) -> None:
        self.s3.put_object(Bucket=self.bucket_name, Key=key, Body=content)

    def write_text_from_list(self, key: str, content: list) -> None:
        content = "\n".join(content)
        self.s3.put_object(Bucket=self.bucket_name, Key=key, Body=content)

    def check_is_parsed(self, split_key: str) -> bool:
        parsed_key = self.get_parsed_key(split_key)
        response = self.s3.list_objects_v2(Bucket=self.bucket_name, Prefix=parsed_key)
        return "Contents" in response

    def save_parsed_hand(self, split_key: str, json_hand: str) -> None:
        parsed_key = self.get_parsed_key(split_key)
        self.s3.put_object(Bucket=self.bucket_name, Key=parsed_key, Body=json_hand)





from pathlib import Path
from setuptools import setup, find_packages
import json


install_requires = [
    "python-dotenv"
]

classifiers = [
    "Development Status :: 4 - Beta",
    "Intended Audience :: Developers",
    "License :: OSI Approved :: MIT License",
    "Natural Language :: English",
    "Programming Language :: Python",
    "Programming Language :: Python :: 3",
    "Topic :: Games/Entertainment",
    "Topic :: Games/Entertainment :: Board Games"
]


def get_version():
    with open("config/version.json", "r") as f:
        version = json.load(f)
        return f"{version['major']}.{version['minor']}.{version['patch']}"


setup(
    name="pkrhistoryparser",
    version=get_version(),
    author="Alexandre MANGWA",
    author_email="alex.mangwa@gmail.com",
    description="A poker package to parse Hand histories into json objects",
    long_description=Path("README.md").read_text(),
    long_description_content_type="text/markdown",
    url="https://github.com/manggy94/PokerHistoryParser",
    project_urls={
        "Bug Tracker": "https://github.com/manggy94/PokerHistoryParser/issues",
        "Documentation": "https://pkrhistoryparser.readthedocs.io/en/latest/parser/"
    },
    classifiers=classifiers,
    packages=find_packages(exclude=["tests", ".venv", "venv", "venv.*"]),
    python_requires=">=3.10",
    install_requires=install_requires,
    license="MIT",
)



"""
This module contains regular expressions used to parse Winamax hand histories.
"""
# HAND HISTORY PATTERNS
PLAYER_PATTERN = r"Seat (\d+): ([\w\s.\-&\⌃]{3,12}) \((\d+)(?:, ([\d\.]+)\D)?"
BLINDS_PATTERN = r"(\n[\w\s\-&.\⌃]{3,12})\s+posts\s+(small blind|big blind|ante)\s+([\d.,]+)"
DATETIME_PATTERN = r"- (\d{4}/\d{2}/\d{2} \d{2}:\d{2}:\d{2}) UTC"
TOURNAMENT_BLINDS_PATTERN = r"\((\d+)/(\d+)/(\d+)\)"
OTHER_BLINDS_PATTERN = r"\(([\d€.]+)/([\d€.]+)\)"
LEVEL_PATTERN = r"level: (\d+)"
NORMAL_BUY_IN_PATTERN = r"buyIn:\s+([\d.,]+)€\s+\+\s+([\d.,]+)€"
KO_BUY_IN_PATTERN = r"buyIn: ([\d.,]+)€ \+ ([\d.,]+)€ \+ ([\d.,]+)€"
FREE_ROLL_PATTERN = r"buyIn: Free"
MAX_PLAYERS_PATTERN = r"(\d+)-max"
BUTTON_SEAT_PATTERN = r"Seat #(\d+) is the button"
TABLE_NAME_PATTERN = r"Table: '(.*)' "
TOURNAMENT_INFO_PATTERN = r"Table: [\'\"]([\w\s\-&\€\:\.\'\"\[\]\!é]+)\((\d+)\)\#(\d+)"
TABLE_IDENT_PATTERN = r"(\(\d+\)#\d+)"
HERO_HAND_PATTERN = r"Dealt to ([\w\s.\-&\⌃]{3,12}) \[(\w\w) (\w\w)\]"
FLOP_PATTERN = r"\*\*\* FLOP \*\*\* \[(\w\w) (\w\w) (\w\w)\]"
TURN_PATTERN = r"\*\*\* TURN \*\*\* \[\w\w \w\w \w\w\]\[(\w\w)\]"
RIVER_PATTERN = r"\*\*\* RIVER \*\*\* \[\w\w \w\w \w\w \w\w\]\[(\w\w)\]"
ACTION_PATTERN = r"\n(?P<pl_name>[\w\s\-&.\⌃]{3,12})\s+(?P<move>calls|bets|raises|folds|checks)(?: (?P<value>\d+))?(?:\sto\s(?P<raise_total>\d+))?(?:(?P<is_all_in>\sand\sis\sall-in))?"
SHOWDOWN_PATTERN = r"((?:(?!\n).)+)\s+shows\s+\[(\w\w) (\w\w)\]"
WINNERS_PATTERN = r"\n([\w\s.\-&\⌃]{3,12}) collected (\d+) from (pot|main pot|side pot \d+)"
HAND_ID_PATTERN = r"HandId: #([\d\-]+)"
PREFLOP_ACTION_PATTERN = r"\*\*\*\sPRE-FLOP\s\*\*\*([&\w\s.€-]+)"
FLOP_ACTION_PATTERN = r"\*\*\*\sFLOP\s\*\*\*\s\[[\w\s]+\]([&\w\s.€-]+)"
TURN_ACTION_PATTERN = r"\*\*\*\sTURN\s\*\*\*\s\[[\w\s]+\]\[[\w\s]+\]([&\w\s.€-]+)"
RIVER_ACTION_PATTERN = r"\*\*\*\sRIVER\s\*\*\*\s\[[\w\s]+\]\[[\w\s]+\]([&\w\s.€-]+)"
STREET_ACTION_PATTERNS = [PREFLOP_ACTION_PATTERN, FLOP_ACTION_PATTERN, TURN_ACTION_PATTERN, RIVER_ACTION_PATTERN]
# TOURNAMENT INFO PATTERNS
SPLIT_PATTERN = r"Winamax\sPoker\s-\sTournament\ssummary"
PRIZE_POOL_PATTERN = r"Prizepool[\s\:]+([\d\.\,]+)\s?€"
REGISTERED_PLAYERS_PATTERN = r"Registered\s+players\s+:\s+(\d+)"
SPEED_PATTERN = r"Speed\s+:\s+(\w+)"
LEVELS_STRUCTURE_PATTERN = r"Levels\s+:\s+\[((.){2,})\]"
START_DATE_PATTERN = r"(\d{4}/\d{2}/\d{2}\s\d{2}:\d{2}:\d{2}\sUTC)"
LEVEL_BLINDS_PATTERN = r"\,?([\dkM\,]+)-([\dkM\,]+):([\dkM\,]+)"
TOURNAMENT_TYPE_PATTERN = r"Type\s+:\s+(\w+)"
SUMMARY_TOURNAMENT_INFO_PATTERN = r"Tournament summary[\:\s]+([\wé\s\-&\€\:\.\'\!\\\[\]]+)\((\d+)\)"
BUY_IN_PATTERN = r"Buy-In[\s\:]+([\d\.\,]+)\s?€\s?\+?\s?([\d\.\,]+)?\s?€?\s?\+\s([\d\.\,]+)"
AMOUNT_WON_PATTERN = r"You\s+won\s+([\d\.\,]+)€"
FINAL_POSITION_PATTERN = r"You\sfinished\sin\s(\d+)"


